@@ -1,7 +1,6 @@
-# /*	all lines except VERSION are C comments
 package Mail::SpamCannibal::DNSBLserver;
 use vars qw($VERSION);
-$VERSION = do { q| */ char version[] = "dnsbls 0.22, 2-9-04"; /* | =~ /(\d+)\.(\d+)/; sprintf("%d.%02d",$1,$2)};
+$VERSION = do { q|char version[] = "dnsbls 0.25, 5-21-04";| =~ /(\d+)\.(\d+)/; sprintf("%d.%02d",$1,$2)};
 # returns $VERSION which is non-zero
 __END__
 
@@ -588,4 +587,5 @@ L<IPTables::IPv4::DBTarpit::Tools>
 
 =cut
 
-# end C comments */
+1;
+
